Examples
=========

The PUQ examples are located in the puq/examples directory. Many of them are used as part
of the tutorial in the :doc:`../users_guide`\.  Here you may be able to find more
details about a particular example.

.. toctree::
   :titlesonly:

   rosen

